This function fits a binary choice model and predicts probabilities for every observations.
fit_and_predict_probabilities(
formula,
data_used,
weights,
method = "logit",
return_model = FALSE,
newdata = NULL,
...
)formula object specifying the conditional probability model.
data.frame with data.
weights variable
method to estimate conditional probabilities
boolean: If FALSE (default), the object of the model
fit used to predict the conditional probabilities for the reweighting factor
are not returned.
data.frame with data to be used for predictions.
other parameters passed to the estimation function.