The function calculates the decomposition terms of the linear
Oaxaca-Blinder decomposition based on the estimated OLS
coefficients and the respective model.matrix.
ob_decompose_calculate_terms(
beta0,
beta1,
X0,
X1,
weights0,
weights1,
reference_0
)vector of estimated coefficients of group 0
vector of estimated coefficients of group 1
model.matrix of group 0
model.matrix of group 1
vector of observation weights of group 0
vector of observation weights of group 1
boolean: indicating if group 0 is the reference group and if its coefficients are used to compute the counterfactual mean.